summaryrefslogtreecommitdiffstats
path: root/python/sip/siplib
diff options
context:
space:
mode:
Diffstat (limited to 'python/sip/siplib')
-rw-r--r--python/sip/siplib/qtlib.c6
-rw-r--r--python/sip/siplib/sip.h2
-rw-r--r--python/sip/siplib/sipint.h2
-rw-r--r--python/sip/siplib/siplib.c12
4 files changed, 11 insertions, 11 deletions
diff --git a/python/sip/siplib/qtlib.c b/python/sip/siplib/qtlib.c
index da7637f1..f3ba4301 100644
--- a/python/sip/siplib/qtlib.c
+++ b/python/sip/siplib/qtlib.c
@@ -278,7 +278,7 @@ sipSignature *sip_api_parse_signature(const char *sig)
case 8:
if (strncmp(dp, "unsigned", 8) == 0)
sat = uint_sat;
- else if (strncmp(dp, "QVariant", 8) == 0)
+ else if (strncmp(dp, "TQVariant", 8) == 0)
{
if (indir == 0)
{
@@ -1153,7 +1153,7 @@ static int saveSlot(sipSlot *sp, PyObject *rxObj, const char *slot)
* because they are generated on the fly and we can't take a
* reference as that may keep the instance (ie. self) alive.
* We therefore treat it as if the user had specified the slot
- * at "obj, SLOT('meth()')" rather than "obj.meth" (see below).
+ * at "obj, TQT_SLOT('meth()')" rather than "obj.meth" (see below).
*/
const char *meth;
@@ -1200,7 +1200,7 @@ static int saveSlot(sipSlot *sp, PyObject *rxObj, const char *slot)
{
/*
* The user has decided to connect a Python signal to a Qt slot and
- * specified the slot as "obj, SLOT('meth()')" rather than "obj.meth".
+ * specified the slot as "obj, TQT_SLOT('meth()')" rather than "obj.meth".
*/
char *tail;
diff --git a/python/sip/siplib/sip.h b/python/sip/siplib/sip.h
index d08a913d..92bcda4e 100644
--- a/python/sip/siplib/sip.h
+++ b/python/sip/siplib/sip.h
@@ -1037,7 +1037,7 @@ typedef struct _sipSignature {
* A connection to a universal slot.
*/
typedef struct _sipSlotConnection {
- /* The transmitter QObject. */
+ /* The transmitter TQObject. */
void *sc_transmitter;
/* The parsed signature. */
diff --git a/python/sip/siplib/sipint.h b/python/sip/siplib/sipint.h
index 97c35631..0a8f2459 100644
--- a/python/sip/siplib/sipint.h
+++ b/python/sip/siplib/sipint.h
@@ -57,7 +57,7 @@ extern PyInterpreterState *sipInterpreter; /* The interpreter. */
extern sipQtAPI *sipQtSupport; /* The Qt support API. */
-extern sipWrapperType *sipQObjectClass; /* The Python QObject class. */
+extern sipWrapperType *sipQObjectClass; /* The Python TQObject class. */
void *sip_api_convert_rx(sipWrapper *txSelf, const char *sigargs,
PyObject *rxObj, const char *slot,
diff --git a/python/sip/siplib/siplib.c b/python/sip/siplib/siplib.c
index d546522c..a715e830 100644
--- a/python/sip/siplib/siplib.c
+++ b/python/sip/siplib/siplib.c
@@ -810,10 +810,10 @@ static int sip_api_export_module(sipExportedModuleDef *client,
return -1;
}
/* Only one module can claim to wrap QObject. */
if (em->em_qt_api != NULL && client->em_qt_api != NULL)
{
- PyErr_Format(PyExc_RuntimeError, "the %s and %s modules both wrap the QObject class", client->em_name, em->em_name);
+ PyErr_Format(PyExc_RuntimeError, "the %s and %s modules both wrap the TQObject class", client->em_name, em->em_name);
return -1;
}
@@ -2510,7 +2510,7 @@ static int parsePass1(sipWrapper **selfp, int *selfargp, int *argsParsedp,
case 'R':
{
- /* Sub-class of QObject. */
+ /* Sub-class of TQObject. */
if (sipQtSupport == NULL || !PyObject_TypeCheck(arg, (PyTypeObject *)sipQObjectClass))
valid = PARSE_TYPE;
@@ -3818,8 +3818,8 @@ static PyObject *handleGetLazyAttr(PyObject *nameobj,sipWrapperType *wt,
* lazy attribute of the same name. In this case (because we
* call the standard getattro code first) this one would be
* wrongly found in preference to the one in the sub-class.
- * The example in PyQt is QScrollView::ResizePolicy and
- * QListView::WidthMode both having a member called Manual.
+ * The example in PyQt is TQScrollView::ResizePolicy and
+ * TQListView::WidthMode both having a member called Manual.
* One way around this might be to cache them in a separate
* dictionary and search that before doing the binary search
* through the lazy enum table.
@@ -6618,7 +6618,7 @@ static void sipWrapper_dealloc(sipWrapper *self)
/*
* Now that the C++ object no longer exists we can tidy up the Python
* object. We used to do this first but that meant lambda slots were
* removed too soon (if they were connected to QObject.destroyed()).
*/
sipWrapper_clear(self);
@@ -810,10 +810,10 @@ static int sip_api_export_module(sipExportedModuleDef *client,
return -1;
}
- /* Only one module can claim to wrap QObject. */
+ /* Only one module can claim to wrap TQObject. */
if (em->em_qt_api != NULL && client->em_qt_api != NULL)
{
@@ -6618,7 +6618,7 @@ static void sipWrapper_dealloc(sipWrapper *self)
* Now that the C++ object no longer exists we can tidy up the Python
* object. We used to do this first but that meant lambda slots were
- * removed too soon (if they were connected to QObject.destroyed()).
+ * removed too soon (if they were connected to TQObject.destroyed()).
*/
sipWrapper_clear(self);